FeatureProvider

Struct FeatureProvider 

pub struct FeatureProvider { /* private fields */ }
Manages the correspondence between edge labels and feature IDs.

Implementations

Source

impl FeatureProvider

pub fn new() -> Self

Creates a new FeatureProvider.

pub fn is_empty(&self) -> bool

Returns true if the manager has no item.

pub fn len(&self) -> usize

Returns the number of items.

pub fn add_feature_set(&mut self, feature_set: FeatureSet) -> Result<NonZeroU32>

Adds a feature set and returns its ID.

Errors

The number of features must be less than 2^32 - 1.